@@ -2,16 +2,16 @@
 #' definitions
 #'
 #' @export
-#' @param ... Curl options passed on to \code{\link[httr]{GET}} (optional)
+#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}}.
+#' optional
 #' @examples \dontrun{
 #' head( homr_definitions() )
 #' }
-
-homr_definitions <- function(...){
-  res <- GET(paste0(homr_base(), "search"), query = list(qid = 'COOP:046742'),
-             ...)
-  out <- utcf8(res)
-  json <- jsonlite::fromJSON(out, FALSE)
+homr_definitions <- function(...) {
+  cli <- crul::HttpClient$new(paste0(homr_base(), "search"), opts = list(...))
+  res <- cli$get(query = list(qid = 'COOP:046742'))
+  res$raise_for_status()
+  json <- jsonlite::fromJSON(res$parse("UTF-8"), FALSE)
   parse_defs(json$stationCollection$definitions)
 }
 
