@@ -2,6 +2,9 @@
 #'
 #' @export
 #' @param path (character) path to the file. required.
+#' @param additional (logical) include additional and remarks data sections
+#' in output. Default: \code{TRUE}. Passed on to
+#' \code{\link[isdparser]{isd_parse}}
 #' @param parallel (logical) do processing in parallel. Default: \code{FALSE}
 #' @param cores (integer) number of cores to use: Default: 2. We look in
 #' your option "cl.cores", but use default value if not found.
@@ -18,11 +21,14 @@
 #' @examples \dontrun{
 #' file <- system.file("examples", "011490-99999-1986.gz", package = "rnoaa")
 #' isd_read(file)
+#' isd_read(file, additional = FALSE)
 #' }
-isd_read <- function(path, parallel = FALSE, cores = getOption("cl.cores", 2),
-                     progress = FALSE) {
+isd_read <- function(path, additional = TRUE, parallel = FALSE,
+                     cores = getOption("cl.cores", 2), progress = FALSE) {
+
   isdparser::isd_parse(
     path = path,
+    additional = additional,
     parallel = parallel,
     cores = cores,
     progress = progress
